@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     AccessTypeType,
@@ -220,7 +220,7 @@ _RequiredCreateChannelRequestRequestTypeDef = TypedDict(
     "_RequiredCreateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
-        "Outputs": List["RequestOutputItemTypeDef"],
+        "Outputs": Sequence["RequestOutputItemTypeDef"],
         "PlaybackMode": PlaybackModeType,
     },
 )
@@ -228,7 +228,7 @@ _OptionalCreateChannelRequestRequestTypeDef = TypedDict(
     "_OptionalCreateChannelRequestRequestTypeDef",
     {
         "FillerSlate": "SlateSourceTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -269,7 +269,7 @@ _RequiredCreateProgramRequestRequestTypeDef = TypedDict(
 _OptionalCreateProgramRequestRequestTypeDef = TypedDict(
     "_OptionalCreateProgramRequestRequestTypeDef",
     {
-        "AdBreaks": List["AdBreakTypeDef"],
+        "AdBreaks": Sequence["AdBreakTypeDef"],
     },
     total=False,
 )
@@ -308,7 +308,7 @@ _OptionalCreateSourceLocationRequestRequestTypeDef = TypedDict(
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -339,7 +339,7 @@ CreateSourceLocationResponseTypeDef = TypedDict(
 _RequiredCreateVodSourceRequestRequestTypeDef = TypedDict(
     "_RequiredCreateVodSourceRequestRequestTypeDef",
     {
-        "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
+        "HttpPackageConfigurations": Sequence["HttpPackageConfigurationTypeDef"],
         "SourceLocationName": str,
         "VodSourceName": str,
     },
@@ -347,7 +347,7 @@ _RequiredCreateVodSourceRequestRequestTypeDef = TypedDict(
 _OptionalCreateVodSourceRequestRequestTypeDef = TypedDict(
     "_OptionalCreateVodSourceRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -855,14 +855,14 @@ PutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
         "AvailSuppression": "AvailSuppressionTypeDef",
         "Bumper": "BumperTypeDef",
         "CdnConfiguration": "CdnConfigurationTypeDef",
-        "ConfigurationAliases": Dict[str, Dict[str, str]],
+        "ConfigurationAliases": Mapping[str, Mapping[str, str]],
         "DashConfiguration": "DashConfigurationForPutTypeDef",
         "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
         "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
         "Name": str,
         "PersonalizationThresholdSeconds": int,
         "SlateAdUrl": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
         "TranscodeProfileName": str,
         "VideoContentSourceUrl": str,
     },
@@ -1069,7 +1069,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -1098,7 +1098,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1106,7 +1106,7 @@ UpdateChannelRequestRequestTypeDef = TypedDict(
     "UpdateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
-        "Outputs": List["RequestOutputItemTypeDef"],
+        "Outputs": Sequence["RequestOutputItemTypeDef"],
     },
 )
 
@@ -1168,7 +1168,7 @@ UpdateSourceLocationResponseTypeDef = TypedDict(
 UpdateVodSourceRequestRequestTypeDef = TypedDict(
     "UpdateVodSourceRequestRequestTypeDef",
     {
-        "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
+        "HttpPackageConfigurations": Sequence["HttpPackageConfigurationTypeDef"],
         "SourceLocationName": str,
         "VodSourceName": str,
     },
